@@ -4,14 +4,17 @@
 # i) worth inversigating the function profile.glm() in MASS MASS profile.glm
 # since it is the function  used for glm models and used in confint.glm()
 # ------------------------------------------------------------------------------
-confint.gamlss  <- function (object, parm, level = 0.95, what="mu", 
-                             robust=FALSE, ...) 
+confint.gamlss  <- function (object, parm, level = 0.95, 
+                         what = c("mu", "sigma", "nu", "tau"), 
+                         parameter = NULL, robust = FALSE, ...) 
 {
 #local function from stats	
 format.perc <- function (probs, digits) 
 paste(format(100 * probs, trim = TRUE, scientific = FALSE, digits = digits), 
     "%")	
 #--------------------------	
+ what <- if (!is.null(parameter))  {
+    match.arg(parameter, choices=c("mu", "sigma", "nu", "tau"))} else  match.arg(what)
   cf <- coef(object, what)
   pnames <- names(cf)
   if (missing(parm))
